#include "gcin.h"
#include <anthy/anthy.h>



struct {
  char *en;
  char *ro;
  char *xx;
} anthy_romaji_map[] = {
{"-",	"ー",	""},
{"a",	"あ",	""},
{"i",	"い",	""},
{"u",	"う",	""},
{"e",	"え",	""},
{"o",	"お",	""},
{"xa",	"ぁ",	""},
{"xi",	"ぃ",	""},
{"xu",	"ぅ",	""},
{"xe",	"ぇ",	""},
{"xo",	"ぉ",	""},
{"la",	"ぁ",	""},
{"li",	"ぃ",	""},
{"lu",	"ぅ",	""},
{"le",	"ぇ",	""},
{"lo",	"ぉ",	""},
{"wi",	"うぃ",	""},
{"we",	"うぇ",	""},
{"wha",	"うぁ",	""},
{"whi",	"うぃ",	""},
{"whe",	"うぇ",	""},
{"who",	"うぉ",	""},
{"va",	"う゛ぁ",	""},
{"vi",	"う゛ぃ",	""},
{"vu",	"う゛",	""},
{"ve",	"う゛ぇ",	""},
{"vo",	"う゛ぉ",	""},
{"ka",	"か",	""},
{"ki",	"き",	""},
{"ku",	"く",	""},
{"ke",	"け",	""},
{"ko",	"こ",	""},
{"ga",	"が",	""},
{"gi",	"ぎ",	""},
{"gu",	"ぐ",	""},
{"ge",	"げ",	""},
{"go",	"ご",	""},
{"kya",	"きゃ",	""},
{"kyi",	"きぃ",	""},
{"kyu",	"きゅ",	""},
{"kye",	"きぇ",	""},
{"kyo",	"きょ",	""},
{"gya",	"ぎゃ",	""},
{"gyi",	"ぎぃ",	""},
{"gyu",	"ぎゅ",	""},
{"gye",	"ぎぇ",	""},
{"gyo",	"ぎょ",	""},
{"sa",	"さ",	""},
{"si",	"し",	""},
{"su",	"す",	""},
{"se",	"せ",	""},
{"so",	"そ",	""},
{"za",	"ざ",	""},
{"zi",	"じ",	""},
{"zu",	"ず",	""},
{"ze",	"ぜ",	""},
{"zo",	"ぞ",	""},
{"sya",	"しゃ",	""},
{"syi",	"しぃ",	""},
{"syu",	"しゅ",	""},
{"sye",	"しぇ",	""},
{"syo",	"しょ",	""},
{"sha",	"しゃ",	""},
{"shi",	"し",	""},
{"shu",	"しゅ",	""},
{"she",	"しぇ",	""},
{"sho",	"しょ",	""},
{"zya",	"じゃ",	""},
{"zyi",	"じぃ",	""},
{"zyu",	"じゅ",	""},
{"zye",	"じぇ",	""},
{"zyo",	"じょ",	""},
{"ja",	"じゃ",	""},
{"jya", "じゃ",	""},
{"ji",	"じ",	""},
{"jyi", "じぃ",	""},
{"ju",	"じゅ",	""},
{"jyu",	"じゅ",	""},
{"je",	"じぇ",	""},
{"jye",	"じぇ",	""},
{"jo",	"じょ",	""},
{"jyo",	"じょ",	""},
{"ta",	"た",	""},
{"ti",	"ち",	""},
{"tu",	"つ",	""},
{"tsu",	"つ",	""},
{"te",	"て",	""},
{"to",	"と",	""},
{"da",	"だ",	""},
{"di",	"ぢ",	""},
{"du",	"づ",	""},
{"de",	"で",	""},
{"do",	"ど",	""},
{"xtu",	"っ",	""},
{"xtsu","っ"	""},
{"ltu",	"っ",	""},
{"ltsu","っ"	""},
{"tya",	"ちゃ",	""},
{"tyi",	"ちぃ",	""},
{"tyu",	"ちゅ",	""},
{"tye",	"ちぇ",	""},
{"tyo",	"ちょ",	""},
{"cha",	"ちゃ",	""},
{"chi",	"ち",	""},
{"chu",	"ちゅ",	""},
{"che",	"ちぇ",	""},
{"cho",	"ちょ",	""},
{"dya",	"ぢゃ",	""},
{"dyi",	"ぢぃ",	""},
{"dyu",	"ぢゅ",	""},
{"dye",	"ぢぇ",	""},
{"dyo",	"ぢょ",	""},
{"tha",	"てゃ",	""},
{"thi",	"てぃ",	""},
{"thu",	"てゅ",	""},
{"the",	"てぇ",	""},
{"tho",	"てょ",	""},
{"dha",	"でゃ",	""},
{"dhi",	"でぃ",	""},
{"dhu",	"でゅ",	""},
{"dhe",	"でぇ",	""},
{"dho",	"でょ",	""},
{"na",	"な",	""},
{"ni",	"に",	""},
{"nu",	"ぬ",	""},
{"ne",	"ね",	""},
{"no",	"の",	""},
{"nya",	"にゃ",	""},
{"nyi",	"にぃ",	""},
{"nyu",	"にゅ",	""},
{"nye",	"にぇ",	""},
{"nyo",	"にょ",	""},
{"ha",	"は",	""},
{"hi",	"ひ",	""},
{"hu",	"ふ",	""},
{"fu",	"ふ",	""},
{"he",	"へ",	""},
{"ho",	"ほ",	""},
{"ba",	"ば",	""},
{"bi",	"び",	""},
{"bu",	"ぶ",	""},
{"be",	"べ",	""},
{"bo",	"ぼ",	""},
{"pa",	"ぱ",	""},
{"pi",	"ぴ",	""},
{"pu",	"ぷ",	""},
{"pe",	"ぺ",	""},
{"po",	"ぽ",	""},
{"hya",	"ひゃ",	""},
{"hyi",	"ひぃ",	""},
{"hyu",	"ひゅ",	""},
{"hye",	"ひぇ",	""},
{"hyo",	"ひょ",	""},
{"bya",	"びゃ",	""},
{"byi",	"びぃ",	""},
{"byu",	"びゅ",	""},
{"bye",	"びぇ",	""},
{"byo",	"びょ",	""},
{"pya",	"ぴゃ",	""},
{"pyi",	"ぴぃ",	""},
{"pyu",	"ぴゅ",	""},
{"pye",	"ぴぇ",	""},
{"pyo",	"ぴょ",	""},
{"fa",	"ふぁ",	""},
{"fi",	"ふぃ",	""},
{"fu",	"ふ",	""},
{"fe",	"ふぇ",	""},
{"fo",	"ふぉ",	""},
{"ma",	"ま",	""},
{"mi",	"み",	""},
{"mu",	"む",	""},
{"me",	"め",	""},
{"mo",	"も",	""},
{"mya",	"みゃ",	""},
{"myi",	"みぃ",	""},
{"myu",	"みゅ",	""},
{"mye",	"みぇ",	""},
{"myo",	"みょ",	""},
{"lya",	"ゃ",	""},
{"xya",	"ゃ",	""},
{"ya",	"や",	""},
{"lyu",	"ゅ",	""},
{"xyu",	"ゅ",	""},
{"yu",	"ゆ",	""},
{"lyo",	"ょ",	""},
{"xyo",	"ょ",	""},
{"yo",	"よ",	""},
{"ra",	"ら",	""},
{"ri",	"り",	""},
{"ru",	"る",	""},
{"re",	"れ",	""},
{"ro",	"ろ",	""},
{"rya",	"りゃ",	""},
{"ryi",	"りぃ",	""},
{"ryu",	"りゅ",	""},
{"rye",	"りぇ",	""},
{"ryo",	"りょ",	""},
{"xwa",	"ゎ",	""},
{"wa",	"わ",	""},
{"wo",	"を",	""},
{"n'",	"ん",	""},
{"nn",	"ん",	""},
{"n",	"ん",	""},
{"wyi",	"ゐ",	""},
{"wye",	"ゑ",	""},
{NULL,	NULL,	NULL},
};


GtkWidget *mainwin;

main(int argc, char **argv)
{
  gtk_init (&argc, &argv);

  if (anthy_init() == -1) {
    printf("cannot init anthy");
    exit(1);
  }


  mainwin = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_default_size(GTK_WINDOW (mainwin), 640, 520);

  g_signal_connect (G_OBJECT (mainwin), "delete_event",
                    G_CALLBACK (exit), NULL);

  GtkWidget *vbox_top = gtk_vbox_new (FALSE, 0);

  anthy_context_t ac = anthy_create_context();

  gtk_widget_show_all(mainwin);

  gtk_main();
}
